#' New SimpleParams
#'
#' Create a new SimpleParams object.
#'
#' @param ... additional parameters passed to \code{\link{setParams}}.
#'
#' @return SimpleParams object.
#' @examples
#' params <- newSimpleParams()
#' @export
newSimpleParams <- function(...) {

    params <- new("SimpleParams")
    params <- setParams(params, ...)

    return(params)
}

setValidity("SimpleParams", function(object) {

    v <- getParams(object, c("nGenes", "nCells", "mean.shape", "mean.rate",
                             "count.disp", "seed"))

    checks <- c(nGenes = checkmate::checkInt(v$nGenes, lower = 1),
                nCells = checkmate::checkInt(v$nCells, lower = 1),
                mean.rate = checkmate::checkNumber(v$mean.rate, lower = 0),
                mean.shape = checkmate::checkNumber(v$mean.shape, lower = 0),
                count.disp = checkmate::checkNumber(v$count.disp, lower = 0),
                seed = checkmate::checkInt(v$seed, lower = 0))

    if (all(checks == TRUE)) {
        valid <- TRUE
    } else {
        valid <- checks[checks != TRUE]
        valid <- paste(names(valid), valid, sep = ": ")
    }

    return(valid)
})

setMethod("show", "SimpleParams", function(object) {

    pp <- list("Mean:"   = c("(Rate)"       = "mean.rate",
                             "(Shape)"      = "mean.shape"),
               "Counts:" = c("[Dispersion]" = "count.disp"))

    callNextMethod()
    showPP(object, pp)
})
